==> dasu_3.02.jar: edu/northwestern/dasu/drools/RuleEngine.java <==
/**
 * Dasu Project
 *
 * File:         RuleEngine.java
 * RCS:          $Id$
 * Description:  RuleEngine class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:28:22 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.drools;

import java.io.File;
import java.util.logging.Logger;

import org.drools.event.rule.ActivationCancelledEvent;
import org.drools.event.rule.ActivationCreatedEvent;
import org.drools.event.rule.AfterActivationFiredEvent;
import org.drools.event.rule.AgendaEventListener;
import org.drools.event.rule.AgendaGroupPoppedEvent;
import org.drools.event.rule.AgendaGroupPushedEvent;
import org.drools.event.rule.BeforeActivationFiredEvent;
import org.drools.logger.KnowledgeRuntimeLoggerFactory;
import org.drools.runtime.rule.FactHandle;

import edu.northwestern.dasu.DasuManager;
import edu.northwestern.dasu.Main;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RuleEngine class ...
 */
public class RuleEngine extends RuleBasedEngine {
	
	private final static Logger LOGGER = Logger.getLogger(RuleEngine.class.getName());
	
	public RuleEngine() throws Exception {
		super("RuleEngine");
	}
	
	@Override
	protected void loadFacts() {
		/* facts addition */
		addFact(DasuManager.systemFact);
		addFact(DasuManager.localPeerFact);
		addFact(DasuManager.localNetworkFact);
	}
	
	@Override
	public boolean loadRules() {
		if (Main.DEBUG) {
			kbase = loadRulesFromDir(Main.getDir() + File.separator + "rules", "base.drl");
			LOGGER.severe("OK if debugging, not for release! Loaded rules from local directory, no verification.");
		} else {
			kbase = loadRules(DasuManager.updater.getRulesData());
			LOGGER.info("Loaded rules version " + DasuManager.updater.getVersion() + ".");
		}
		
		ksession = kbase.newStatefulKnowledgeSession();
		ksession.addEventListener(new Listener());
		
		if (Main.DEBUG) {
			logger = KnowledgeRuntimeLoggerFactory.newFileLogger(ksession, "test");	
		}
		
		return true;
	}
	
	public class Listener implements AgendaEventListener {

		public void agendaGroupPopped(AgendaGroupPoppedEvent arg0) {}
		public void agendaGroupPushed(AgendaGroupPushedEvent arg0) {}
		public void activationCancelled(ActivationCancelledEvent arg0) {}
		public void activationCreated(ActivationCreatedEvent arg0) {}

		public void afterActivationFired(AfterActivationFiredEvent event) {
			for (FactHandle fh : event.getActivation().getFactHandles()) {
				//System.out.println("!!!!!!!!afterActivationFired: " + event);				
				getModifiedFacts().remove(fh);
			}
		}

		public void beforeActivationFired(BeforeActivationFiredEvent event) {
			for (FactHandle fh : event.getActivation().getFactHandles()) {
				//System.out.println("!!!!!!!!beforeActivationFired: " + event);
				getModifiedFacts().add(fh);
			}			
		}
		
	}
}

==> dasu_4.11.jar: edu/northwestern/dasu/drools/RuleEngine.java <==
/**
 * Dasu Project
 *
 * File:         RuleEngine.java
 * RCS:          $Id$
 * Description:  RuleEngine class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:28:22 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.drools;

import java.io.File;
import java.util.logging.Logger;

import org.drools.event.rule.ActivationCancelledEvent;
import org.drools.event.rule.ActivationCreatedEvent;
import org.drools.event.rule.AfterActivationFiredEvent;
import org.drools.event.rule.AgendaEventListener;
import org.drools.event.rule.AgendaGroupPoppedEvent;
import org.drools.event.rule.AgendaGroupPushedEvent;
import org.drools.event.rule.BeforeActivationFiredEvent;
import org.drools.logger.KnowledgeRuntimeLoggerFactory;
import org.drools.runtime.rule.FactHandle;

import edu.northwestern.dasu.DasuManager;
import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.measurement.types.SourceType;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The RuleEngine class ...
 */
public class RuleEngine extends RuleBasedEngine {
	
	private final static Logger LOGGER = Logger.getLogger("edu.northwestern.dasu");
	
	public RuleEngine(SourceType engineId) throws Exception {
		super("DasuRuleEngine", engineId);
	}
	
	@Override
	protected void loadFacts() {
		/* facts addition */
		addFact(DasuManager.systemFact, this.getEngineId());
		addFact(DasuManager.localPeerFact, this.getEngineId());
		addFact(DasuManager.localNetworkFact, this.getEngineId());
	}
		
	public boolean loadRules() throws Exception {
		
		if (Main.RE_DEBUG_SKIP_VERIFICATION) {
			kbase = loadRulesFromDir(Main.getDir() + File.separator + "rules", "base.drl");
			LOGGER.severe("RULEENGINE: OK if debugging, not for release! Loaded rules from local directory, no verification.");
		} else {
			kbase = loadRules(DasuManager.updater.getRulesData());
			LOGGER.info("RULEENGINE: RuleEngine.class: Loaded rules version " + DasuManager.updater.getVersion() + ".");
		}
				
		ksession = kbase.newStatefulKnowledgeSession();
		ksession.addEventListener(new Listener());
		
		return true;
	}
	
	public class Listener implements AgendaEventListener {

		public void agendaGroupPopped(AgendaGroupPoppedEvent arg0) {}
		public void agendaGroupPushed(AgendaGroupPushedEvent arg0) {}
		public void activationCancelled(ActivationCancelledEvent arg0) {}
		public void activationCreated(ActivationCreatedEvent arg0) {}

		public void afterActivationFired(AfterActivationFiredEvent event) {
			for (FactHandle fh : event.getActivation().getFactHandles()) {			
				getModifiedFacts().remove(fh);
			}
		}

		public void beforeActivationFired(BeforeActivationFiredEvent event) {
			for (FactHandle fh : event.getActivation().getFactHandles()) {
				getModifiedFacts().add(fh);
			}			
		}
		
	}
}
